@@ -2,18 +2,16 @@
 
 # NOTE: This file resides in the _util/target directory to ensure compatibility with all supported Python versions.
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
 REMOTE_ONLY_PYTHON_VERSIONS = (
-    '2.7',
-    '3.5',
-    '3.6',
-    '3.7',
-)
-
-CONTROLLER_PYTHON_VERSIONS = (
     '3.8',
     '3.9',
     '3.10',
 )
+
+CONTROLLER_PYTHON_VERSIONS = (
+    '3.11',
+    '3.12',
+    '3.13',
+)
